@@ -14,18 +14,15 @@ structures.
 
 =head1 VERSION
 
-Version 0.04
+Version 0.05
 
 =cut
 
-our $VERSION = '0.04';
+our $VERSION = '0.05';
 
-=head1 PREREQUISITES
+=head1 PRE-REQUISITES
 
 The Smotif-based modeling algorithm requires the query protein sequence as input. 
-Additionally, if the structure of the protein is known from any alternate
-resource, then a PDB-formatted structure file is required. This pdb-file can be
-present in a centralized local directory or a user-designated separate directory. 
 
 Software / data:
 
@@ -42,9 +39,10 @@ Software / data:
 Download and install the above mentioned software / data according to their instructions. 
 Note: Psipred and Psiblast require legacy blast and Delta-blast is a part of the Blast+ package. 
 
-Databases required: 
+=head1 DATABASES REQUIRED: 
 
 1. PDBAA blast database is required (ftp://ftp.ncbi.nlm.nih.gov/blast/db/). 
+
 2. HHsuite databases NR20 and PDB70 are required (ftp://toolkit.genzentrum.lmu.de/pub/HH-suite/databases/hhsuite_dbs/)
 
 =head1 DOWNLOAD AND INSTALLATION
@@ -55,11 +53,11 @@ http://search.cpan.org/dist/SmotifTF/
 
 Installation of the software (also available in the README file):
 
- tar -zxvf SmotifTF-0.01.tar.gz
+ tar -zxvf SmotifTF-version.tar.gz
 
- cd SmotifTF-0.01/
+ cd SmotifTF-version/
 
- perl Makefile.PL PREFIX=/home/user/SmotifTF-0.01
+ perl Makefile.PL 
 
  make
 
@@ -67,7 +65,7 @@ Installation of the software (also available in the README file):
 
  make install
 
-Set up the configuration file:
+=head1 SET UP THE CONFIGURATION FILE:
 
 The configuration file, smotiftf_config.ini has all the information
 regarding the required library files and other pre-requisite software. 
@@ -76,7 +74,7 @@ Set all the paths and executables in this file correctly.
 
 Set environment varible in .bashrc file:
 
-export SMOTIFTF_CONFIG_FILE=/home/user/SmotifTF-0.01/smotiftf_config.ini
+export SMOTIFTF_CONFIG_FILE=/home/user/MyPerlLib/share/perl5/SmotifTF-version/smotiftf_config.ini
 
 =head1 MODELING ALGORITHMIC STEPS
 
@@ -96,7 +94,6 @@ export SMOTIFTF_CONFIG_FILE=/home/user/SmotifTF-0.01/smotiftf_config.ini
       |                                                    |
       |   Multi-core / cluster job                         |
       |   Usage: perl smotiftf.pl --step=1 --pdb=1zzz      |
-      |               --chain=A --havestructure=0          | 
        ----------------------------------------------------
 
        ----------------------------------------------------
@@ -105,7 +102,6 @@ export SMOTIFTF_CONFIG_FILE=/home/user/SmotifTF-0.01/smotiftf_config.ini
       |                                                    |
       |   Multi-core / cluster job                         |
       |   Usage: perl smotiftf.pl --step=2 --pdb=1zzz      |
-      |               --chain=A --havestructure=0          |  
        ----------------------------------------------------
 
        ----------------------------------------------------
@@ -115,7 +111,6 @@ export SMOTIFTF_CONFIG_FILE=/home/user/SmotifTF-0.01/smotiftf_config.ini
       |                                                    |
       |   Multi-core / cluster job                         |
       |   Usage: perl smotiftf.pl --step=3 --pdb=1zzz      |
-      |               --chain=A --havestructure=0          |
        ----------------------------------------------------
 
        ----------------------------------------------------
@@ -125,7 +120,6 @@ export SMOTIFTF_CONFIG_FILE=/home/user/SmotifTF-0.01/smotiftf_config.ini
       |                                                    |
       |   Single-core job                                  |
       |   Usage: perl smotiftf.pl --step=4 --pdb=1zzz      |
-      |               --chain=A --havestructure=0          |
        ----------------------------------------------------
 
        ----------------------------------------------------
@@ -135,37 +129,42 @@ export SMOTIFTF_CONFIG_FILE=/home/user/SmotifTF-0.01/smotiftf_config.ini
       |                                                    |
       |   Single-core job                                  |
       |   Usage: perl smotiftf.pl --step=5 --pdb=1zzz      |
-      |               --chain=A --havestructure=0          |    
        ----------------------------------------------------
 
-=head1 HOW TO RUN SmotifTF
+=head1 HOW TO RUN SMOTIFTF
 
-1. Create a subdirectory with a dummy pdb file name (eg: 1abc or 1zzz). 
+1. The two perl scripts needed to run SmotifTF are:
+   smotiftf_prereq.pl and smotiftf.pl
+   If installed locally, provide the correct path name to the 
+   SmotifTF perl library in both scripts.
 
-2. Put the query fasta file (1zzz.fasta) in this directory.
+2. Create a subdirectory with a dummy pdb file name (eg: 1abc or 1zzz). 
 
-3. Optional: If structure is known, include a pdb format structure file
-   in the same directory. 1abc/pdb1abc.ent or 1zzz/pdb1zzz.ent
+3. Put the query fasta file (1zzz.fasta) in this directory.
 
 4. Run the pre-requisites first. This runs Psipred, HHblits+HHsearch,
-   Psiblast and Delta-blast. It will then generate the dynamic database of
-   Smotifs and the list of putative Smotifs in the query protein. Follow the
-   instructions given in smotiftf_prereq.pl. 
-   perl smotiftf_prereq.pl --step=all --sequence_file=1zzz.fasta --dir=1zzz 
+   Psiblast and Delta-blast. Input is the query sequence in fasta format 
+   and the outputs are (a) dynamic database of Smotifs and (b) the putative 
+   Smotifs in the query protein. These are used in the subsequent modeling 
+   steps. Follow the instructions given in smotiftf_prereq.pl. For more 
+   information about the pre-requisites use: perl smotiftf_prereq.pl -help
 
-4. Run steps 1 to 5 as given above sequentially. Output from previous
-   steps are often required in subsequent steps. Wait for each step to
-   be completed without errors before going to the next step. 
+   Usage: perl smotiftf_prereq.pl --step=all --sequence_file=1zzz.fasta --dir=1zzz 
 
-5. To run steps 1-5 together use: 
-   perl smotiftf.pl --step=all --pdb=1zzz --chain=A --havestructure=0
+6. After the pre-requisites are completed, run steps 1 to 5 as given 
+   above sequentially. Output from previous steps are often required 
+   in subsequent steps. Wait for each step to be completed without 
+   errors before going to the next step. Follow the instructions given 
+   in smotiftf.pl. For more information use: perl smotiftf.pl -help
 
-6. Use multiple-cores or clusters as available, for steps 1 & 3 above.  
+   Usage: perl smotiftf.pl --step=[1-5] --pdb=1zzz
+
+7. To run steps 1-5 together use: 
+   perl smotiftf.pl --step=all --pdb=1zzz
+
+8. Use multiple-cores or clusters as available, for steps 1 & 3 above.  
    These are slow and require a lot of computational resources. 
 
-7. If structure is known, use --havestructure=1.
-   Else, use --havestructure=0 in all the steps. 
-
 Results: 
 
 Top 5 models are stored in the subdirectory (1abc or 1zzz) as:
