@@ -12,7 +12,7 @@ use File::Spec::Functions qw(catfile);
 BEGIN {
     use Exporter ();
     our ( $VERSION, @ISA, @EXPORT, @EXPORT_OK, %EXPORT_TAGS);
-    $VERSION = "0.1";
+    $VERSION = "0.01";
 
     @ISA = qw(Exporter);
 
@@ -48,11 +48,10 @@ Version 0.01
 
 our $VERSION = '0.01';
 
-
 =head1 SYNOPSIS
 
-This module compare the given query Smotif to all the Smotifs in the dynamic database,
-computes e-values using the HHsuite and provided a list of suitable Smotifs based on
+Subroutines to compare a given query Smotif to all the Smotifs in the dynamic database,
+compute e-values using the HHsuite and provide a list of suitable Smotifs based on
 the e-values. 
 
     use CompareSmotifs;
@@ -463,18 +462,14 @@ sub read_dd_info {
     return (@ddlist);
 }
 
-=head1 AUTHOR
+=head1 AUTHORS
 
-Brinda Vallat, Vilas Menon , C<< <brinda at fiserlab.org andras@fiserlab.org> >>
+Fiserlab memebers, C<< <andras at fiserlab.org> >>
 
 =head1 BUGS
 
 Please report any bugs or feature requests to C<bug-. at rt.cpan.org>, or through
-the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=.>.  I will be notified, and then you'll
-automatically be notified of progress on your bug as I make changes.
-
-
-
+the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=.>.
 
 =head1 SUPPORT
 
@@ -482,9 +477,6 @@ You can find documentation for this module with the perldoc command.
 
     perldoc CompareSmotifs
 
-
-You can also look for information at:
-
 =over 4
 
 =item * RT: CPAN's request tracker (report bugs here)
@@ -505,10 +497,6 @@ L<http://search.cpan.org/dist/./>
 
 =back
 
-
-=head1 ACKNOWLEDGEMENTS
-
-
 =head1 LICENSE AND COPYRIGHT
 
 Copyright 2015 Brinda Vallat, Vilas Menon .
