@@ -16,6 +16,12 @@ use SmotifTF::GeometricalCalculations;
 
 HHblits 
 
+=head1 VERSION
+
+Version 0.01 
+
+=cut
+
 our $VERSION = '0.01';
 
 =head1 SYNOPSIS
@@ -345,18 +351,14 @@ sub parse  {
 
 
 
-=head1 AUTHOR
+=head1 AUTHORS
 
 Fiserlab Members , C<< <andras at fiserlab.org> >>
 
 =head1 BUGS
 
 Please report any bugs or feature requests to C<bug-. at rt.cpan.org>, or through
-the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=.>.  I will be notified, and then you'll
-automatically be notified of progress on your bug as I make changes.
-
-
-
+the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=.>.
 
 =head1 SUPPORT
 
@@ -364,9 +366,6 @@ You can find documentation for this module with the perldoc command.
 
     perldoc HHblits
 
-
-You can also look for information at:
-
 =over 4
 
 =item * RT: CPAN's request tracker (report bugs here)
@@ -387,10 +386,6 @@ L<http://search.cpan.org/dist/./>
 
 =back
 
-
-=head1 ACKNOWLEDGEMENTS
-
-
 =head1 LICENSE AND COPYRIGHT
 
 Copyright 2015 Fiserlab Members .
