@@ -7,9 +7,8 @@ use warnings;
 BEGIN {
     use Exporter ();
     our ( $VERSION, @ISA, @EXPORT, @EXPORT_OK, %EXPORT_TAGS);
-    $VERSION = "0.1";
+    $VERSION = "0.01";
 
-    #$AUTHOR  = "Vilas Menon(vilas\@fiserlab.org )";
     @ISA = qw(Exporter);
 
     # name of the functions to export
@@ -67,7 +66,7 @@ our $VERSION = '0.01';
 
 =head1 SYNOPSIS
 
-Subroutines that connect to the MYSQL database (obsolete for SmotifTF)
+Set of routines that connect to the MYSQL database (obsolete for SmotifTF)
 
 =head2 connect_to_mysql 
 
@@ -277,16 +276,14 @@ sub get_matching_smotifs {
     return $aref;
 }
 
-=head1 AUTHOR
+=head1 AUTHORS
 
 Fiserlab Members , C<< <andras at fiserlab.org> >>
 
 =head1 BUGS
 
 Please report any bugs or feature requests to C<bug-. at rt.cpan.org>, or through
-the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=.>.  I will be notified, and then you'll
-automatically be notified of progress on your bug as I make changes.
-
+the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=.>.
 
 =head1 SUPPORT
 
@@ -294,9 +291,6 @@ You can find documentation for this module with the perldoc command.
 
     perldoc MYSQLSmotifs
 
-
-You can also look for information at:
-
 =over 4
 
 =item * RT: CPAN's request tracker (report bugs here)
@@ -317,10 +311,6 @@ L<http://search.cpan.org/dist/./>
 
 =back
 
-
-=head1 ACKNOWLEDGEMENTS
-
-
 =head1 LICENSE AND COPYRIGHT
 
 Copyright 2015 Fiserlab Members .
