@@ -26,12 +26,11 @@ our $VERSION = '0.01';
 
 This package contains the 'Protein' class used to represent a protein 
 structure composed of smotifs and the set of subroutines available for 
-constructing, modifying, and evaluating the given protein structure
+constructing, modifying, and evaluating the given protein structure.
 
     use Protein;
-
     my $test = Protein->new();
-    ...
+
 
 =head2 new
 
@@ -2197,19 +2196,40 @@ sub coords_from_torsion {
 }
 
 
-=head1 AUTHOR
+=head1 AUTHORS
 
 Fiserlab Members , C<< <andras at fiserlab.org> >>
 
 =head1 BUGS
 
 Please report any bugs or feature requests to C<bug-. at rt.cpan.org>, or through
-the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=.>.  I will be notified, and then you'll
-automatically be notified of progress on your bug as I make changes.
+the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=.>.
 
+=head1 SUPPORT
 
-=head1 ACKNOWLEDGEMENTS
+You can find documentation for this module with the perldoc command.
 
+    perldoc Protein
+
+=over 4
+
+=item * RT: CPAN's request tracker (report bugs here)
+
+L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=.>
+
+=item * AnnoCPAN: Annotated CPAN documentation
+
+L<http://annocpan.org/dist/.>
+
+=item * CPAN Ratings
+
+L<http://cpanratings.perl.org/d/.>
+
+=item * Search CPAN
+
+L<http://search.cpan.org/dist/./>
+
+=back
 
 =head1 LICENSE AND COPYRIGHT
 
