@@ -6,10 +6,14 @@ use warnings;
 
 use Carp;
 use File::Spec::Functions qw(catfile catdir);
+
 =head1 NAME
 
 Psiblast 
 
+=head1 VERSION
+
+Version 0.01
 
 =cut
 
@@ -190,18 +194,14 @@ sub run_deltablast {
 }
 
 
-=head1 AUTHOR
+=head1 AUTHORS
 
 Fiserlab Members , C<< <andras at fiserlab.org> >>
 
 =head1 BUGS
 
 Please report any bugs or feature requests to C<bug-. at rt.cpan.org>, or through
-the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=.>.  I will be notified, and then you'll
-automatically be notified of progress on your bug as I make changes.
-
-
-
+the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=.>.
 
 =head1 SUPPORT
 
@@ -209,9 +209,6 @@ You can find documentation for this module with the perldoc command.
 
     perldoc Psiblast
 
-
-You can also look for information at:
-
 =over 4
 
 =item * RT: CPAN's request tracker (report bugs here)
@@ -232,10 +229,6 @@ L<http://search.cpan.org/dist/./>
 
 =back
 
-
-=head1 ACKNOWLEDGEMENTS
-
-
 =head1 LICENSE AND COPYRIGHT
 
 Copyright 2015 Fiserlab Members .
