@@ -3,21 +3,15 @@ use warnings;
 use strict;
 use Data::Dumper;
 # 
-# It runs  smotifab pre-requisites
+# It runs  smotiftf pre-requisites
 #
 #    Pre-requisites
-#    1. Get FASTA sequence (from user). 
+#    1. Get FASTA sequence. 
 #    2. Run Psipred (- get .horiz and .ss2 files). 
 #    3. Run HHblits  and get hhr file 
 #    4. Run psi-blast and delta-blast 
 #
-
-#
-# perl smotifab_prereq.pl --sequence_file=4wyq.fasta --step=1 --dir=./
-#
-use lib "/home/cmadrid/test/lib/perl5/site_perl/5.8.8/";
-# use lib "/home/brinda/MyLib/share/perl5/";
-# use lib "/home/cmadrid/test/share/perl5/";
+#use lib "/home/user/MyPerlLib/share/perl5/";
 use SmotifTF;
 
 use SmotifTF::Psipred;
@@ -44,7 +38,7 @@ my $MAX_PROCESSES = $localrun->{'max_proc'};
 
 my $sequence_file;
 #my $pdb;
-my $chain;
+#my $chain;
 my $step = 0;
 my $dir;
 my $verbose;
@@ -52,7 +46,7 @@ my $verbose;
 my $man  = 0;
 my $help = 0;
 
-# smotifab_prereq.pl -s 4wyq.fasta -d ./
+# smotiftf_prereq.pl -s 4wyq.fasta -d ./
 my $result = GetOptions(
     "sequence_file=s" => \$sequence_file,  #  string
 #    "chain=s"         => \$chain,          # string
@@ -577,15 +571,25 @@ SmotifTF Template-free Modeling Method - The pre-requisites
 
 =head1 SYNOPSIS
 
-Please read this document completely for running the SmotifTF
-software successfully on any local computer. 
+SmotifTF carries out template-free structure prediction using a dynamic library 
+of supersecondary structure fragments obtained from a set of remotely related 
+PDB structures. 
 
-Pre-requisites: 
+This perl script runs all the pre-requisites (HHblits/HHsearch, Psi-Blast, 
+Delta-Blast and Psipred) required for modeling. The input is the query
+protein sequence in fasta format and the outputs are: 
+
+1. A dynamic library of supersecondary structure motifs, tailor-made for the 
+   query protein (obtained using HHblits/HHsearch, Psi-Blast and Delta-Blast). 
+
+2. Definitions for putative Smotifs in the query protein (obtained from Psipred). 
+
+Once the pre-requisites are completed, modeling can be carried out using the 
+script smotiftf.pl (use "perldoc smotiftf.pl" for instructions). 
+
+=head1 PRE-REQUISITES
 
 The Smotif-based modeling algorithm requires the query protein sequence as input. 
-Additionally, if the structure of the protein is known from any alternate
-resource, then a PDB-formatted structure file is required. This pdb-file can be
-present in a centralized local directory or a user-designated separate directory. 
 
 Software / data:
 
@@ -606,9 +610,11 @@ Note: Psipred and Psiblast require legacy blast and Delta-blast is a part of the
 Databases required: 
 
 1. PDBAA blast database is required (ftp://ftp.ncbi.nlm.nih.gov/blast/db/). 
+
 2. HHsuite databases NR20 and PDB70 are required (ftp://toolkit.genzentrum.lmu.de/pub/HH-suite/databases/hhsuite_dbs/)
 
-SmotifTF Download and Installation: 
+=head1 SMOTIFTF DOWNLOAD AND INSTALLATION
+
 
 Download SmotifTF package from CPAN: 
 
@@ -616,11 +622,11 @@ http://search.cpan.org/dist/SmotifTF/
 
 Installation of the software (also available in the README file):
 
- tar -zxvf SmotifTF-0.01.tar.gz
+ tar -zxvf SmotifTF-version.tar.gz
 
- cd SmotifTF-0.01/
+ cd SmotifTF-version/
 
- perl Makefile.PL PREFIX=/home/user/SmotifTF-0.01
+ perl Makefile.PL PREFIX=/home/user/MyPerlLib/
 
  make
 
@@ -628,19 +634,21 @@ Installation of the software (also available in the README file):
 
  make install
 
-Set up the configuration file:
+=head1 SETUP CONFIGURATION FILE
 
-The configuration file, smotifab_config.ini has all the information
+
+The configuration file, smotiftf_config.ini has all the information
 regarding the required library files and other pre-requisite software. 
 
 Set all the paths and executables in this file correctly.
 
 Set environment varible in .bashrc file:
 
-export SMOTIFTF_CONFIG_FILE=/home/user/SmotifTF-0.01/smotiftf_config.ini
+export SMOTIFTF_CONFIG_FILE=/home/user/MyPerlLib/share/perl5/SmotifTF-version/smotiftf_config.ini
 
 
- Pre-requisites steps: 
+=head1 PRE-REQUISITES STEPS
+
 
       -------------------------------------------------------
      | Run Pre-requisites:                                   |
@@ -653,30 +661,34 @@ export SMOTIFTF_CONFIG_FILE=/home/user/SmotifTF-0.01/smotiftf_config.ini
       -------------------------------------------------------
 
 
-How to run the pre-requisites program:
+=head1 HOW TO RUN THE PRE-REQUISITES
 
 
-1. Create a subdirectory with a dummy pdb file name (eg: 1abc or 1zzz). 
+1. If installed locally, provide the correct path name to the 
+   SmotifTF perl library in this perl script (line 14).
 
-2. Put the query fasta file (1zzz.fasta) in this directory.
+2. Create a subdirectory with a dummy pdb file name (eg: 1abc or 1zzz). 
 
-3. Optional: If structure is known, include a pdb format structure file
-   in the same directory. 1abc/pdb1abc.ent or 1zzz/pdb1zzz.ent
+3. Put the query fasta file (1zzz.fasta) in this directory.
 
 4. Run the pre-requisites step first. This runs Psipred, HHblits+HHsearch,
    Psiblast and Delta-blast. It will then generate the dynamic database of
    Smotifs and the list of putative Smotifs in the query protein.
+   For more information about the pre-requisites use: 
+   perl smotiftf_prereq.pl -help
+
    Usage: perl smotiftf_prereq.pl --sequence_file=1zzz.fasta --dir=1zzz --step=all
 
-5. Next, run smotiftf.pl according to the instructions given there.  
+5. Next, run smotiftf.pl according to the instructions given there. For more 
+   information use: perl smotiftf.pl -help
 
-Reference: 
+=head1 REFERENCE
 
 Vallat BK, Fiser A.
 Modularity of protein folds as a tool for template-free modeling of sequences
 Manuscript under review. 
 
-Authors:
+=head1 AUTHORS
 
 Brinda Vallat, Carlos Madrid and Andras Fiser. 
 
@@ -694,7 +706,7 @@ Prints the manual page and exits.
 
 =item B<--step>
 
-1,2,3,4,5,6,7,8 or all
+1,2,3,4,5,6,7,8 or all (to run all steps consecutively)
 
 =item B<--sequence_file>
  
